CVS: jcontainer/loom/engine/src/java/org/jcontainer/loom/components/util/profile ComponentProfile.java,1.2,1.3 PartitionProfile.java,1.1,1.2

Peter Donald <pdonald-yCVjj/[email protected]> Mon, 3 Nov 2003 00:43:19 -0600
Newsgroups gmane.comp.java.jcontainer.cvs
Message-ID <[email protected]>
Update of /cvsroot/jcontainer/jcontainer/loom/engine/src/java/org/jcontainer/loom/components/util/profile
In directory hogshead.codehaus.org:/tmp/cvs-serv22178/engine/src/java/org/jcontainer/loom/components/util/profile

Modified Files:
	ComponentProfile.java PartitionProfile.java 
Log Message:
Rename the MetaData away from standard MetaData postfix to use more readily accesisble names


Index: PartitionProfile.java
===================================================================
RCS file: /cvsroot/jcontainer/jcontainer/loom/engine/src/java/org/jcontainer/loom/components/util/profile/PartitionProfile.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -d -r1.1 -r1.2
--- PartitionProfile.java	16 Oct 2003 14:45:47 -0000	1.1
+++ PartitionProfile.java	3 Nov 2003 06:43:15 -0000	1.2
@@ -7,7 +7,7 @@
  */
 package org.jcontainer.loom.components.util.profile;
 
-import org.jcontainer.loom.components.util.metadata.PartitionMetaData;
+import org.jcontainer.loom.components.util.metadata.PartitionTemplate;
 
 /**
  * The PartitionProfile contains the set of data required
@@ -26,9 +26,9 @@
     public static final PartitionProfile[] EMPTY_SET = new PartitionProfile[ 0 ];
 
     /**
-     * The {@link org.jcontainer.loom.components.util.metadata.PartitionMetaData} for this partition.
+     * The PartitionTemplate for this partition.
      */
-    private final PartitionMetaData m_metaData;
+    private final PartitionTemplate m_metaData;
 
     /**
      * An array of partitions that are contained by this
@@ -49,7 +49,7 @@
      * @param partitions the partitions contained by this partition
      * @param components the components contained by this partition
      */
-    public PartitionProfile( final PartitionMetaData metaData,
+    public PartitionProfile( final PartitionTemplate metaData,
                              final PartitionProfile[] partitions,
                              final ComponentProfile[] components )
     {
@@ -76,7 +76,7 @@
      *
      * @return the metaData about this profile.
      */
-    public PartitionMetaData getMetaData()
+    public PartitionTemplate getMetaData()
     {
         return m_metaData;
     }
@@ -129,7 +129,7 @@
         for( int i = 0; i < m_components.length; i++ )
         {
             final ComponentProfile component = m_components[ i ];
-            if( component.getMetaData().getName().equals( name ) )
+            if( component.getTemplate().getName().equals( name ) )
             {
                 return component;
             }
Index: ComponentProfile.java
===================================================================
RCS file: /cvsroot/jcontainer/jcontainer/loom/engine/src/java/org/jcontainer/loom/components/util/profile/ComponentProfile.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -d -r1.2 -r1.3
--- ComponentProfile.java	3 Nov 2003 06:19:27 -0000	1.2
+++ ComponentProfile.java	3 Nov 2003 06:43:15 -0000	1.3
@@ -8,13 +8,13 @@
 package org.jcontainer.loom.components.util.profile;
 
 import org.jcontainer.loom.components.util.info.ComponentInfo;
-import org.jcontainer.loom.components.util.metadata.ComponentMetaData;
+import org.jcontainer.loom.components.util.metadata.ComponentTemplate;
 
 /**
  * The ComponentProfile defines a component as a conjunction
  * of the ComponentInfo and ComponentMetaData.
  * The ComponentInfo defines the type of the component
  * and the ComponentMetaData defines the data required to
  * construct a specific instance of the component.
  *
  * @author <a href="mailto:peter at realityforge.org">Peter Donald</a>
@@ -34,18 +34,18 @@
     private final ComponentInfo m_info;
 
     /**
-     * The ComponentMetaData that describes
+     * The ComponentTemplate that describes
      * this component.
      */
-    private final ComponentMetaData m_metaData;
+    private final ComponentTemplate m_metaData;
 
     /**
      * Creation of a new <code>ComponentProfile</code> instance.
      *
      * @param metaData the ComponentMetaData instance defining the component.
      */
     public ComponentProfile( final ComponentInfo info,
-                             final ComponentMetaData metaData )
+                             final ComponentTemplate metaData )
     {
         if( null == info )
         {
@@ -70,10 +70,10 @@
     }
 
     /**
      * Returns the underlying ComponentMetaData instance.
      * @return the component meta data instance
      */
-    public ComponentMetaData getMetaData()
+    public ComponentTemplate getTemplate()
     {
         return m_metaData;
     }
@@ -8,13 +8,13 @@
 /**
  * The ComponentProfile defines a component as a conjunction
- * of the ComponentInfo and ComponentMetaData.
+ * of the ComponentInfo and ComponentTemplate.
  * The ComponentInfo defines the type of the component
@@ -8,13 +8,13 @@
  * The ComponentInfo defines the type of the component
- * and the ComponentMetaData defines the data required to
+ * and the ComponentTemplate defines the data required to
  * construct a specific instance of the component.
  *
@@ -34,18 +34,18 @@
      * Creation of a new <code>ComponentProfile</code> instance.
      *
-     * @param metaData the ComponentMetaData instance defining the component.
+     * @param metaData the ComponentTemplate instance defining the component.
      */
     public ComponentProfile( final ComponentInfo info,
@@ -70,10 +70,10 @@
 
     /**
-     * Returns the underlying ComponentMetaData instance.
+     * Returns the underlying ComponentTemplate instance.
      * @return the component meta data instance
      */
